@@ -270,10 +270,9 @@ int nla_parse(struct nlattr *tb[], int maxtype, struct nlattr *head, int len,
 	nla_for_each_attr(nla, head, len, rem) {
 		int type = nla_type(nla);
 
-		if (type == 0) {
-			fprintf(stderr, "Illegal nla->nla_type == 0\n");
+		/* Padding attributes */
+		if (type == 0)
 			continue;
-		}
 
 		if (type <= maxtype) {
 			if (policy) {
